![banner](https://raw.githubusercontent.com/Enchan1207/blueprintpy/HEAD/banner.png)

[![pypi](https://img.shields.io/pypi/v/blueprintpy)](https://pypi.org/project/blueprintpy/)

## Overview

Generic package configuration CLI generator

## Description

**blueprintpy** is a generic utility that provides package configuration CLI like `npm init` or `swift init`.

By default it contains generic pypi-compliant Python package and CMake-compliant C++ configuration, but you can customize it.  
Furthermore, each configuration is managed as template using [Jinja2](https://jinja.palletsprojects.com/en/3.1.x/), so you can create your own template.

## Installation

blueprintpy can be installed from PyPI. The CLI tool `blueprint` will also be installed.

```
pip install blueprintpy
```


## Documents

Documents and API references are publised at [GitHub Pages](https://enchan1207.github.io/blueprintpy/index.html).  

## License

This repository is published under [MIT License](https://github.com/Enchan1207/blueprintpy/blob/HEAD/LICENSE).
